==> meutils-2024.8.8.15.22.48.tar.gz: meutils-2024.8.8.15.22.48/meutils/apis/siliconflow/api_images.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : text_to_image
# @Time         : 2024/7/8 12:19
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://docs.siliconflow.cn/reference/stabilityaistable-diffusion-3-medium_text-to-image

from meutils.pipe import *
from meutils.pipe import storage_to_cookie
from meutils.config_utils.lark_utils import get_spreadsheet_values, get_next_token_for_polling
from meutils.schemas.openai_types import ImageRequest, ImagesResponse
from meutils.apis.translator import deeplx
from meutils.schemas.translator_types import DeeplxRequest
from meutils.decorators.retry import retrying

BASE_URL = "https://cloud.siliconflow.cn"
FEISHU_URL = "https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=InxiCF"
FEISHU_URL_TOKEN = "https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=xlvlrH"


# https://cloud.siliconflow.cn/api/redirect/model?modelName=black-forest-labs/FLUX.1-schnell&modelSubType=text-to-image

@retrying(max_retries=3, title=__name__)
async def create_image(request: ImageRequest):
    cookie = await get_next_token_for_polling(feishu_url=FEISHU_URL_TOKEN)
    print(cookie)

    prompt = (await deeplx.translate(DeeplxRequest(text=request.prompt, target_lang="EN"))).get("data")

    params = {
        "modelName": request.model,  # stabilityai/stable-diffusion-3-medium
        "modelSubType": "text-to-image"
    }

    data = f'{{"image_size":"{request.size}","batch_size":{request.n},' \
           f'"num_inference_steps":{request.num_inference_steps},"guidance_scale":{request.guidance_scale},'

    if request.negative_prompt:
        data += f'"negative_prompt":"{request.negative_prompt}",'

    if request.seed:
        data += f'"seed":{request.seed},'

    data += f'"prompt":"{prompt}"}}'

    headers = {
        'Cookie': cookie,
    }

    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=100, follow_redirects=True) as client:
        response = await client.post("/api/redirect/model", params=params, content=data)
        if response.is_success:
            data = response.json().get('images', [])
            return ImagesResponse(data=data)

        response.raise_for_status()


@retrying(max_retries=3, title=__name__)
async def api_create_image(request: ImageRequest, api_key: Optional[str] = None):  # SD3
    api_key = api_key or await get_next_token_for_polling(feishu_url=FEISHU_URL)

    base_url = "https://api.siliconflow.cn/v1"
    model = "black-forest-labs/FLUX.1-schnell"  # 默认
    if request.model.startswith(("stable-diffusion-3",)):  # todo
        pass
        # model = request.model
        # model = "stabilityai/stable-diffusion-3-medium"

    prompt = (await deeplx.translate(DeeplxRequest(text=request.prompt, target_lang="EN"))).get("data")
    payload = {
        "prompt": prompt,
        "image_size": request.size,
        "batch_size": request.n,
        "num_inference_steps": request.num_inference_steps,
        "guidance_scale": request.guidance_scale,
    }
    headers = {
        "Authorization": f"Bearer {api_key}",
    }
    async with httpx.AsyncClient(base_url=base_url, headers=headers, timeout=100) as client:
        response = await client.post(f"{model}/text-to-image", json=payload)

        if response.is_success:
            data = response.json().get('images', [])
            return ImagesResponse(data=data)
        response.raise_for_status()


if __name__ == '__main__':
    # cookie = await get_next_token_for_polling(feishu_url="https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=xlvlrH")
    # api_key = storage_to_cookie(cookie)

    # storage_state = get_spreadsheet_values(feishu_url="https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=xlvlrH",
    #                            to_dataframe=True)[0]

    # cookie = storage_to_cookie(storage_state[0])

    request = ImageRequest(
        # model="stabilityai/stable-diffusion-3-medium",
        model="black-forest-labs/FLUX.1-schnell",
        prompt="一条可爱的狗"
    )
    print(arun(create_image(request)))

    # arun(get_next_token_for_polling(feishu_url=FEISHU_URL_TOKEN))
    # request = ImageRequest(
    #     prompt="画条狗",
    #     model="stabilityai/stable-diffusion-3-medium"
    # )
    #
    # with timer():
    #     arun(
    #         api_create_image(
    #             request
    #         )
    #     )
    #
    # request = ImageRequest(
    #     prompt="画条狗",
    #     model="black-forest-labs/FLUX.1-schnell"
    # )
    # with timer():
    #     arun(
    #         api_create_image(
    #             request
    #         )
    #     )

==> meutils-2024.8.21.16.17.48.tar.gz: meutils-2024.8.21.16.17.48/meutils/apis/siliconflow/api_images.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : text_to_image
# @Time         : 2024/7/8 12:19
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://docs.siliconflow.cn/reference/stabilityaistable-diffusion-3-medium_text-to-image

from meutils.pipe import *
from meutils.pipe import storage_to_cookie
from meutils.config_utils.lark_utils import get_spreadsheet_values, get_next_token_for_polling
from meutils.schemas.openai_types import ImageRequest, ImagesResponse
from meutils.apis.translator import deeplx
from meutils.schemas.translator_types import DeeplxRequest
from meutils.decorators.retry import retrying

BASE_URL = "https://cloud.siliconflow.cn"
FEISHU_URL = "https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=InxiCF"
FEISHU_URL_TOKEN = "https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=xlvlrH"


# https://cloud.siliconflow.cn/api/redirect/model?modelName=black-forest-labs/FLUX.1-schnell&modelSubType=text-to-image

@retrying(max_retries=3, title=__name__)
async def create_image(request: ImageRequest):
    cookie = await get_next_token_for_polling(feishu_url=FEISHU_URL_TOKEN)
    print(cookie)

    prompt = (await deeplx.translate(DeeplxRequest(text=request.prompt, target_lang="EN"))).get("data")

    params = {
        "modelName": request.model,  # stabilityai/stable-diffusion-3-medium
        "modelSubType": "text-to-image"
    }

    data = f'{{"image_size":"{request.size}","batch_size":{request.n},' \
           f'"num_inference_steps":{request.num_inference_steps},"guidance_scale":{request.guidance_scale},'

    if request.negative_prompt:
        data += f'"negative_prompt":"{request.negative_prompt}",'

    if request.seed:
        data += f'"seed":{request.seed},'

    data += f'"prompt":"{prompt}"}}'

    headers = {
        'Cookie': cookie,
    }

    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=100, follow_redirects=True) as client:
        response = await client.post("/api/redirect/model", params=params, content=data)
        if response.is_success:
            data = response.json().get('images', [])
            return ImagesResponse(data=data)

        response.raise_for_status()


@retrying(max_retries=5, title=__name__)
async def api_create_image(request: ImageRequest, api_key: Optional[str] = None):  # SD3
    api_key = api_key or await get_next_token_for_polling(feishu_url=FEISHU_URL)

    base_url = "https://api.siliconflow.cn/v1"
    model = "black-forest-labs/FLUX.1-schnell"  # 默认
    if request.model.startswith(("stable-diffusion-3",)):  # todo
        pass
        # model = request.model
        # model = "stabilityai/stable-diffusion-3-medium"

    prompt = (await deeplx.translate(DeeplxRequest(text=request.prompt, target_lang="EN"))).get("data")
    payload = {
        "prompt": prompt,
        "image_size": request.size,
        "batch_size": request.n,
        "num_inference_steps": request.num_inference_steps,
        "guidance_scale": request.guidance_scale,
    }
    headers = {
        "Authorization": f"Bearer {api_key}",
    }
    async with httpx.AsyncClient(base_url=base_url, headers=headers, timeout=100) as client:
        response = await client.post(f"{model}/text-to-image", json=payload)

        if response.is_success:
            data = response.json().get('images', [])
            return ImagesResponse(data=data)
        response.raise_for_status()  # 451


if __name__ == '__main__':
    # cookie = await get_next_token_for_polling(feishu_url="https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=xlvlrH")
    # api_key = storage_to_cookie(cookie)

    # storage_state = get_spreadsheet_values(feishu_url="https://xchatllm.feishu.cn/sheets/Bmjtst2f6hfMqFttbhLcdfRJnNf?sheet=xlvlrH",
    #                            to_dataframe=True)[0]

    # cookie = storage_to_cookie(storage_state[0])

    # request = ImageRequest(
    #     # model="stabilityai/stable-diffusion-3-medium",
    #     # model="black-forest-labs/FLUX.1-schnell",
    #     model="black-forest-labs/FLUX.1-dev",
    #
    #     prompt="一条可爱的狗 做爱"
    # )
    # print(arun(create_image(request)))

    # arun(get_next_token_for_polling(feishu_url=FEISHU_URL_TOKEN))
    # request = ImageRequest(
    #     prompt="画条狗",
    #     model="stabilityai/stable-diffusion-3-medium"
    # )
    #
    # with timer():
    #     arun(
    #         api_create_image(
    #             request
    #         )
    #     )
    #
    prompt = """
    - Role: 艺术家
- Background: 用户想要一个笑脸大佛的图像，这通常与佛教文化和积极情绪相关。
- Profile: 你是一位擅长绘制佛教艺术的艺术家，了解佛教象征和笑脸的表达。
- Skills: 绘画技巧、对佛教文化的理解、表情绘制能力。
- Goals: 创建一个笑脸大佛的图像，传达宁静与快乐的感觉。
- Constrains: 图像应该是正面的，大佛的面部表情应该是明显的笑容。
- OutputFormat: 一个简单的线条画，突出大佛的笑脸特征。
- Workflow:
  1. 绘制大佛的轮廓，包括头部和身体的基本形状。
  2. 细化面部特征，确保眼睛微闭，嘴角上扬，形成微笑。
  3. 添加其他佛教象征元素，如光环或莲花座。
- Examples: 
  - 一个简单的笑脸大佛线条画，面部表情温和，带有微笑。
- Initialization: 欢迎来到笑脸大佛的创作空间，让我们一起绘制一个充满宁静与喜悦的佛像。
    """
    request = ImageRequest(
        prompt=prompt,
        model="black-forest-labs/FLUX.1-schnell"
    )
    with timer():
        arun(
            api_create_image(
                request
            )
        )
